pub enum ExitError {
}Expand description
Exit error reason.
Variants
StackUnderflow
Trying to pop from an empty stack.
StackOverflow
Trying to push into a stack over stack limit.
InvalidJump
Jump destination is invalid.
InvalidRange
An opcode accesses memory region, but the region is invalid.
DesignatedInvalid
Encountered the designated invalid opcode.
CallTooDeep
Call stack is too deep (runtime).
CreateCollision
Create opcode encountered collision (runtime).
CreateContractLimit
Create init code exceeds limit (runtime).
OutOfOffset
An opcode accesses external information, but the request is off offset limit (runtime).
OutOfGas
Execution runs out of gas (runtime).
OutOfFund
Not enough fund to start the execution (runtime).
PCUnderflow
PC underflowed (unused).
CreateEmpty
Attempt to create an empty account (runtime, unused).
Other(Cow<'static, str>)
Other normal errors.